@@ -16,12 +16,14 @@ class TestSeaDataManager(unittest.TestCase):
         self.df = pd.DataFrame(random_data, index=time_index)
         survey_location = bpnsdata.geolocation.SurveyLocation('test_data/VG.gpx')
         self.geodf = survey_location.geotrackpoints
+        self.geodf.loc[self.geodf.iloc[0].name, 'geometry'] = shapely.geometry.Point()
 
     def test_sea_data_manager(self):
         env_vars = ['shipping', 'time', 'wrakken_bank', 'habitat_suitability',
-                    'seabed_habitat', 'sea_surface', 'sea_wave', 'rain', 'wind']
+                    'seabed_habitat', 'sea_surface', 'sea_wave', 'rain', 'wind', 'bathymetry']
         self.manager = bpnsdata.SeaDataManager(env_vars)
-        self.manager(self.geodf)
+        df = self.manager(self.geodf)
+        print(df)
 
     def test_geolocation(self):
         survey_location = bpnsdata.geolocation.SurveyLocation('test_data/VG.gpx')
